# -*- coding: utf-8 -*-
#
# Andreas Dahlberg <andoz_90@hotmail.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 1, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have receiv# Statusmessage displayed while playinged a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

from xlgui import panel
from xl import event, settings
from xl.nls import gettext as _
import dbus
import musictrackerprefs
import sys


class Musictracker(object):
	
    def __inner_preference(klass):
        def getter(self):
            return settings.get_option(klass.name, klass.default or None)
            
        def setter(self, val):
            settings.set_option(klass.name, val)

        return property(getter, setter)

    show_playmessage   = __inner_preference(musictrackerprefs.ShowPlaymessage)
    show_pausemessage  = __inner_preference(musictrackerprefs.ShowPausemessage)
    clear_message      = __inner_preference(musictrackerprefs.ClearMessage)
    playmessage        = __inner_preference(musictrackerprefs.Playmessage)
    pausemessage       = __inner_preference(musictrackerprefs.Pausemessage)
    playstatus         = __inner_preference(musictrackerprefs.Playstatus) 
    pausestatus        = __inner_preference(musictrackerprefs.Pausestatus) 
 
    def __init__(self, exaile):
        self.exaile = exaile
        event.add_callback(self.playing_message,'playback_player_start')
        event.add_callback(self.playing_message,'playback_player_resume')
        event.add_callback(self.pause_message,'playback_player_pause')
        event.add_callback(self.pause_message,'playback_player_end')      
        event.add_callback(self.nuke_message, 'quit_application')
      
    def playing_message(self, type, player, track):
		
		try:
			title = ''.join(track['title'])
		except:
			title = 'Unknown'
		
		try:	
			artist = ''.join(track['artist'])
		except:	
			artist = 'Unknown'

		try:
			album = ''.join(track['album'])
		except:	
			album = 'Unknown'
        
		if self.show_playmessage:
			statusmessage = self.playmessage.replace('%title', title).replace('%artist', artist).replace('%album', album)
			send_status(statusmessage, self.playstatus)
		else:
			send_status('', 'None')
 
    
    def pause_message(self, type, player, track):
        if self.show_pausemessage:
            send_status(self.pausemessage, self.pausestatus)
        else:
			send_status('', 'None')
			
    def nuke_message(self, type, player, track):
		if self.clear_message:
			send_status('', 'None')
		else:
			pass

bus = dbus.SessionBus()
	
STATUS_AVAILABLE = dbus.Int32(2)
STATUS_BUSY = dbus.Int32(3)
STATUS_AWAY = dbus.Int32(5)
MUSICTRACKER_PLUGIN = None

 
def send_status(message, status):
	try:
		purple = bus.get_object('im.pidgin.purple.PurpleService', '/im/pidgin/purple/PurpleObject')
	
		if status == 'Available':
			new_status = purple.PurpleSavedstatusNew('', STATUS_AVAILABLE)	
		elif status == 'Busy':
			new_status = purple.PurpleSavedstatusNew('', STATUS_BUSY)
		elif status == 'Away':
			new_status = purple.PurpleSavedstatusNew('', STATUS_AWAY)
		else:
			new_status = purple.PurpleSavedstatusGetCurrent()  

            
		purple.PurpleSavedstatusSetMessage(new_status, message)	     
		purple.PurpleSavedstatusActivate(new_status, message)    
	except:
		print 'Could not connect to im.pidgin.purple.PurpleService'
		print 'Check if pidgin is running...'
		
		
def get_prefs_pane():
    return musictrackerprefs


def enable(exaile):
    global MUSICTRACKER_PLUGIN    
    MUSICTRACKER_PLUGIN = Musictracker(exaile)


def disable(exaile):
    if MUSICTRACKER_PLUGIN.clear_message: 
		send_status('', 'None')
